@@ -1,6 +1,6 @@
-#!/usr/bin/env bash
+#!/bin/sh
 
-find -name '*.svg' -exec xmllint --noout {} + 2> xmlerrors
+find . -name '*.svg' -exec xmllint --noout {} + 2> xmlerrors
 if [ -s xmlerrors ]; then
     cat xmlerrors
     rm xmlerrors
